@@ -1,7 +1,7 @@
 __title__ = "spacy-stanza"
-__version__ = "0.2.1"
+__version__ = "1.0.1"
 __summary__ = "Use the latest Stanza (StanfordNLP) research models directly in spaCy"
 __uri__ = "https://explosion.ai"
-__author__ = "Ines Montani"
-__email__ = "ines@explosion.ai"
+__author__ = "Explosion"
+__email__ = "contact@explosion.ai"
 __license__ = "MIT"
